"""Auto-generated file, do not edit by hand. AU metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AU = PhoneMetadata(id='AU', country_code=61, international_prefix='(?:14(?:1[14]|34|4[17]|[56]6|7[47]|88)0011)|001[14-689]',
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{4,9}|[2-578]\\d{8}', possible_length=(5, 6, 7, 8, 9, 10), possible_length_local_only=(8,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[237]\\d{8}|8(?:[6-8]\\d{3}|9(?:[02-9]\\d{2}|1(?:[0-57-9]\\d|6[0135-9])))\\d{4}', example_number='212345678', possible_length=(9,), possible_length_local_only=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='14(?:5\\d|71)\\d{5}|4(?:[0-3]\\d|4[47-9]|5[0-25-9]|6[6-9]|7[02-9]|8[147-9]|9[017-9])\\d{6}', example_number='412345678', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='180(?:0\\d{3}|2)\\d{3}', example_number='1800123456', possible_length=(7, 10)),
    premium_rate=PhoneNumberDesc(national_number_pattern='19(?:0[0126]\\d|[679])\\d{5}', example_number='1900123456', possible_length=(8, 10)),
    shared_cost=PhoneNumberDesc(national_number_pattern='13(?:00\\d{3}|45[0-4]|\\d)\\d{3}', example_number='1300123456', possible_length=(6, 8, 10)),
    personal_number=PhoneNumberDesc(national_number_pattern='500\\d{6}', example_number='500123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='550\\d{6}', example_number='550123456', possible_length=(9,)),
    pager=PhoneNumberDesc(national_number_pattern='16\\d{3,7}', example_number='1612345', possible_length=(5, 6, 7, 8, 9)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='1(?:3(?:00\\d{3}|45[0-4]|\\d)\\d{3}|80(?:0\\d{6}|2\\d{3}))', example_number='1300123456', possible_length=(6, 7, 8, 10)),
    preferred_international_prefix='0011',
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='([2378])(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[2378]'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[45]|14'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(16)(\\d{3,4})', format='\\1 \\2', leading_digits_pattern=['16'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(16)(\\d{3})(\\d{2,4})', format='\\1 \\2 \\3', leading_digits_pattern=['16'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(1[389]\\d{2})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['1(?:[38]0|90)', '1(?:[38]00|90)'], national_prefix_formatting_rule='\\1'),
        NumberFormat(pattern='(180)(2\\d{3})', format='\\1 \\2', leading_digits_pattern=['180', '1802'], national_prefix_formatting_rule='\\1'),
        NumberFormat(pattern='(19\\d)(\\d{3})', format='\\1 \\2', leading_digits_pattern=['19[13]'], national_prefix_formatting_rule='\\1'),
        NumberFormat(pattern='(19\\d{2})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['19[679]'], national_prefix_formatting_rule='\\1'),
        NumberFormat(pattern='(13)(\\d{2})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['13[1-9]'], national_prefix_formatting_rule='\\1')],
    main_country_for_code=True,
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. KR metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_KR = PhoneMetadata(id='KR', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{2,3}', possible_length=(3, 4)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:1[78]|28|330|82)', example_number='118', possible_length=(3, 4)),
    emergency=PhoneNumberDesc(national_number_pattern='11[29]', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:0[01]|1[027-9]|2[01389]|3(?:2|3[039]|45|66|88|9[18])|82)', example_number='112', possible_length=(3, 4)),
    carrier_specific=PhoneNumberDesc(national_number_pattern='10[01]', example_number='100', possible_length=(3,)),
    short_data=True)



"""Auto-generated file, do not edit by hand. TR metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_TR = PhoneMetadata(id='TR', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[125]\\d{2,3}', possible_length=(3, 4)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:1[02]|55)', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:1[02]|55)|(?:28|5[4-6])\\d{2}', example_number='112', possible_length=(3, 4)),
    standard_rate=PhoneNumberDesc(national_number_pattern='2850|5420', example_number='5420', possible_length=(4,)),
    sms_services=PhoneNumberDesc(national_number_pattern='(?:28|5[4-6])\\d{2}', example_number='5420', possible_length=(4,)),
    short_data=True)
